aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/c/c_api_internal.h
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/c/c_api_internal.h')
-rw-r--r--tensorflow/c/c_api_internal.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tensorflow/c/c_api_internal.h b/tensorflow/c/c_api_internal.h
index aac333d9e2..6df77a7f9b 100644
--- a/tensorflow/c/c_api_internal.h
+++ b/tensorflow/c/c_api_internal.h
@@ -143,11 +143,11 @@ struct TF_ImportGraphDefOptions {
struct TF_ImportGraphDefResults {
std::vector<TF_Output> return_tensors;
std::vector<TF_Operation*> return_nodes;
- std::vector<const char*> unused_key_names;
- std::vector<int> unused_key_indexes;
+ std::vector<const char*> missing_unused_key_names;
+ std::vector<int> missing_unused_key_indexes;
- // Backing memory for unused_key_names values.
- std::list<tensorflow::string> unused_key_names_data;
+ // Backing memory for missing_unused_key_names values.
+ std::list<tensorflow::string> missing_unused_key_names_data;
};
struct TF_DeviceList {